@@ -31,12 +31,12 @@ DEGENERACY_THRESHOLD = 1e-3
 EIGVEC_THRESHOLD = 1e-3
 
 # regular expression pattern for a time stamp or other signifier of timing output, "CLOCK" or "TIME" or "SECONDS", & system-dependent versioning
-skip_criteria = re.compile('([A-Z][a-z][a-z] [A-Z][a-z][a-z] [ 0-9][0-9] [0-9][0-9]:[0-9][0-9]:[0-9][0-9] [0-9][0-9][0-9][0-9])'
-                           '|(CLOCK)|(TIME)|(SECONDS)|(Version)|(THE VIBRATIONAL FREQUENCY)|(ITERATION)|(SCF CALCULATIONS)|(Stewart)'
-                           '|(remaining)|(\*  THREADS)|(\*  ISOTOPE)|(\*  DENOUT)|(\*  OLDENS)|(\*  SETUP)|(ITER.)|(\*\* )|(web-site)|(MOPAC)|(GRADIENT NORM)')
+skip_criteria = re.compile(r'([A-Z][a-z][a-z] [A-Z][a-z][a-z] [ 0-9][0-9] [0-9][0-9]:[0-9][0-9]:[0-9][0-9] [0-9][0-9][0-9][0-9])'
+                           r'|(CLOCK)|(TIME)|(SECONDS)|(Version)|(THE VIBRATIONAL FREQUENCY)|(ITERATION)|(SCF CALCULATIONS)|(Stewart)'
+                           r'|(remaining)|(\*  THREADS)|(\*  ISOTOPE)|(\*  DENOUT)|(\*  OLDENS)|(\*  SETUP)|(ITER.)|(\*\* )|(web-site)|(MOPAC)|(GRADIENT NORM)')
 
 # regular expression pattern for an eigenvector block
-eigen_criteria = re.compile('(Root No.)|(ROOT NO.)')
+eigen_criteria = re.compile(r'(Root No.)|(ROOT NO.)')
 
 def is_float(string):
     '''check if a string contains a float'''
@@ -213,6 +213,14 @@ def compare_mopac_out_file(out_line, out_list, ref_line, ref_list, heat_error_th
     '''Compares the output to the given reference'''
 
     if len(ref_list) != len(out_list):
+        dump = open("ref.dump", "w")
+        for item in ref_list:
+            dump.write(f"{item}\n")
+        dump.close()
+        dump = open("out.dump", "w")
+        for item in out_list:
+            dump.write(f"{item}\n")
+        dump.close()
         assert len(ref_list) == len(out_list), f'ERROR: output file size mismatch, {len(ref_list)} vs. {len(out_list)}'
         #print(f'WARNING: output file size mismatch, {len(ref_list)} vs. {len(out_list)}')
 
